@@ -42,4 +42,10 @@ DEF_ORDER_BY = "_id"
 
 REDIS_LPR_DATA_LIST_PREFIX = "lpr_data_list"
 
-CORRELATION_ID_HEADER_KEY_NAME="X-Request-ID"
+CORRELATION_ID_HEADER_KEY_NAME = "X-Request-ID"
+
+SOURCE_SMART_WORKSHOP_IMPORTED_SERVICE_TICKET = 'SmartWorkshopImportedServiceTicket'
+SOURCE_SMART_WORKSHOP_UPDATE_SERVICE_TICKET = 'SmartWorkshopUpdateServiceTicket'
+SOURCE_SMART_WORKSHOP_IMPORTED_DMS_DATA = 'SmartWorkshopImportedDMSData'
+SOURCE_WEBHOOK = 'Webhook'
+SOURCE_SMART_WORKSHOP = 'SmartWorkshopManual'
\ No newline at end of file
